/* This file was generated by syncqt. */
#ifndef QT_QTSERIALBUS_VERSION_H
#define QT_QTSERIALBUS_VERSION_H

#define QTSERIALBUS_VERSION_STR "5.15.18"

#define QTSERIALBUS_VERSION 0x050F12

#endif // QT_QTSERIALBUS_VERSION_H
